import type { ZodLiteral, ZodObject, ZodOptional, ZodString } from 'zod';
import z from 'zod';
import type { ZodRawShape } from 'zod/lib/types';
export declare const GENERATED_BASE_EVENT_SCHEMA: ZodObject<{
    id: ZodString;
    timestamp: ZodString;
}, "strip", z.ZodTypeAny, {
    id: string;
    timestamp: string;
}, {
    id: string;
    timestamp: string;
}>;
export declare const OPTIONAL_GENERATED_BASE_EVENT_SCHEMA: ZodObject<{
    id: ZodOptional<ZodString>;
    timestamp: ZodOptional<ZodString>;
}, "strip", z.ZodTypeAny, {
    id?: string | undefined;
    timestamp?: string | undefined;
}, {
    id?: string | undefined;
    timestamp?: string | undefined;
}>;
export declare const CORE_EVENT_SCHEMA: ZodObject<{
    type: ZodLiteral<string>;
    payload: ZodOptional<ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
}, "strip", z.ZodTypeAny, {
    type: string;
    payload?: {} | undefined;
}, {
    type: string;
    payload?: {} | undefined;
}>;
export declare const CONSUMER_BASE_EVENT_SCHEMA: ZodObject<z.objectUtil.extendShape<{
    id: ZodString;
    timestamp: ZodString;
}, {
    type: ZodLiteral<string>;
    payload: ZodOptional<ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
}>, "strip", z.ZodTypeAny, {
    id: string;
    timestamp: string;
    type: string;
    payload?: {} | undefined;
}, {
    id: string;
    timestamp: string;
    type: string;
    payload?: {} | undefined;
}>;
export declare const PUBLISHER_BASE_EVENT_SCHEMA: ZodObject<z.objectUtil.extendShape<{
    id: ZodOptional<ZodString>;
    timestamp: ZodOptional<ZodString>;
}, {
    type: ZodLiteral<string>;
    payload: ZodOptional<ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
}>, "strip", z.ZodTypeAny, {
    type: string;
    id?: string | undefined;
    timestamp?: string | undefined;
    payload?: {} | undefined;
}, {
    type: string;
    id?: string | undefined;
    timestamp?: string | undefined;
    payload?: {} | undefined;
}>;
export type ConsumerBaseEventType = z.infer<typeof CONSUMER_BASE_EVENT_SCHEMA>;
export type PublisherBaseEventType = z.infer<typeof PUBLISHER_BASE_EVENT_SCHEMA>;
export type CoreEventType = z.infer<typeof CORE_EVENT_SCHEMA>;
export type GeneratedBaseEventType = z.infer<typeof GENERATED_BASE_EVENT_SCHEMA>;
type ReturnType<T extends ZodObject<Y>, Y extends ZodRawShape, Z extends string> = {
    consumerSchema: ZodObject<{
        id: ZodString;
        timestamp: ZodString;
        type: ZodLiteral<Z>;
        payload: T;
    }>;
    publisherSchema: ZodObject<{
        id: ZodOptional<ZodString>;
        timestamp: ZodOptional<ZodString>;
        type: ZodLiteral<Z>;
        payload: T;
    }>;
};
export declare function enrichEventSchemaWithBase<T extends ZodObject<Y>, Y extends ZodRawShape, Z extends string>(type: Z, payloadSchema: T): ReturnType<T, Y, Z>;
export {};
