"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enrichEventSchemaWithBase = exports.PUBLISHER_BASE_EVENT_SCHEMA = exports.CONSUMER_BASE_EVENT_SCHEMA = exports.CORE_EVENT_SCHEMA = exports.OPTIONAL_GENERATED_BASE_EVENT_SCHEMA = exports.GENERATED_BASE_EVENT_SCHEMA = void 0;
const tslib_1 = require("tslib");
const zod_1 = tslib_1.__importDefault(require("zod"));
// Base event fields that are typically autogenerated
exports.GENERATED_BASE_EVENT_SCHEMA = zod_1.default.object({
    id: zod_1.default.string().describe('event unique identifier'),
    timestamp: zod_1.default.string().datetime().describe('iso 8601 datetime'),
});
// Base event fields that are typically autogenerated, marked as optional
exports.OPTIONAL_GENERATED_BASE_EVENT_SCHEMA = zod_1.default.object({
    id: zod_1.default.string().describe('event unique identifier').optional(),
    timestamp: zod_1.default.string().datetime().describe('iso 8601 datetime').optional(),
});
// Base event fields that are always defined manually
exports.CORE_EVENT_SCHEMA = zod_1.default.object({
    type: zod_1.default.literal('<replace.me>').describe('event type name'),
    payload: zod_1.default.optional(zod_1.default.object({})).describe('event payload based on type'),
});
// Core fields that describe either internal event or external message
exports.CONSUMER_BASE_EVENT_SCHEMA = exports.GENERATED_BASE_EVENT_SCHEMA.extend(exports.CORE_EVENT_SCHEMA.shape);
exports.PUBLISHER_BASE_EVENT_SCHEMA = exports.OPTIONAL_GENERATED_BASE_EVENT_SCHEMA.extend(exports.CORE_EVENT_SCHEMA.shape);
function enrichEventSchemaWithBase(type, payloadSchema) {
    const baseSchema = zod_1.default.object({
        type: zod_1.default.literal(type),
        payload: payloadSchema,
    });
    const consumerSchema = exports.GENERATED_BASE_EVENT_SCHEMA.merge(baseSchema);
    const publisherSchema = exports.OPTIONAL_GENERATED_BASE_EVENT_SCHEMA.merge(baseSchema);
    return {
        consumerSchema: consumerSchema,
        publisherSchema: publisherSchema,
    };
}
exports.enrichEventSchemaWithBase = enrichEventSchemaWithBase;
//# sourceMappingURL=baseEventSchemas.js.map