import z, { type ZodLiteral, type ZodObject, type ZodOptional, type ZodString } from 'zod';
import type { ZodRawShape } from 'zod/lib/types';
import type { CommonEventDefinition } from '../events/eventTypes';
export declare const MESSAGE_METADATA_SCHEMA: z.ZodObject<{
    schemaVersion: z.ZodString;
    producedBy: z.ZodString;
    originatedFrom: z.ZodString;
    correlationId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    schemaVersion: string;
    producedBy: string;
    originatedFrom: string;
    correlationId: string;
}, {
    schemaVersion: string;
    producedBy: string;
    originatedFrom: string;
    correlationId: string;
}>;
export declare const MESSAGE_SCHEMA_EXTENSION: {
    metadata: z.ZodOptional<z.ZodObject<{
        schemaVersion: z.ZodString;
        producedBy: z.ZodString;
        originatedFrom: z.ZodString;
        correlationId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        schemaVersion: string;
        producedBy: string;
        originatedFrom: string;
        correlationId: string;
    }, {
        schemaVersion: string;
        producedBy: string;
        originatedFrom: string;
        correlationId: string;
    }>>;
};
export declare const BASE_MESSAGE_SCHEMA: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    id: z.ZodString;
    timestamp: z.ZodString;
}, {
    type: z.ZodLiteral<string>;
    payload: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
}>, {
    metadata: z.ZodOptional<z.ZodObject<{
        schemaVersion: z.ZodString;
        producedBy: z.ZodString;
        originatedFrom: z.ZodString;
        correlationId: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        schemaVersion: string;
        producedBy: string;
        originatedFrom: string;
        correlationId: string;
    }, {
        schemaVersion: string;
        producedBy: string;
        originatedFrom: string;
        correlationId: string;
    }>>;
}>, "strip", z.ZodTypeAny, {
    id: string;
    timestamp: string;
    type: string;
    payload?: {} | undefined;
    metadata?: {
        schemaVersion: string;
        producedBy: string;
        originatedFrom: string;
        correlationId: string;
    } | undefined;
}, {
    id: string;
    timestamp: string;
    type: string;
    payload?: {} | undefined;
    metadata?: {
        schemaVersion: string;
        producedBy: string;
        originatedFrom: string;
        correlationId: string;
    } | undefined;
}>;
export type BaseMessageType = z.infer<typeof BASE_MESSAGE_SCHEMA>;
export type MessageMetadataType = z.infer<typeof MESSAGE_METADATA_SCHEMA>;
export type CommonMessageDefinitionSchemaType<T extends CommonEventDefinition> = z.infer<T['consumerSchema']>;
type ReturnType<T extends ZodObject<Y>, Y extends ZodRawShape, Z extends string> = {
    consumerSchema: ZodObject<{
        id: ZodString;
        timestamp: ZodString;
        type: ZodLiteral<Z>;
        payload: T;
        metadata: ZodOptional<ZodObject<{
            schemaVersion: ZodString;
            producedBy: ZodString;
            originatedFrom: ZodString;
            correlationId: ZodString;
        }>>;
    }>;
    publisherSchema: ZodObject<{
        id: ZodOptional<ZodString>;
        timestamp: ZodOptional<ZodString>;
        type: ZodLiteral<Z>;
        payload: T;
        metadata: ZodOptional<ZodObject<{
            schemaVersion: ZodString;
            producedBy: ZodString;
            originatedFrom: ZodString;
            correlationId: ZodString;
        }>>;
    }>;
};
export declare function enrichMessageSchemaWithBase<T extends ZodObject<Y>, Y extends ZodRawShape, Z extends string>(type: Z, payloadSchema: T): ReturnType<T, Y, Z>;
export {};
